import { useState, useEffect } from 'react'
import { showInputOverlay, setupAutoInputOverlay, onInputOverlaySubmit } from '../../utils/InputOverlayHelper'
import './InputDemo.sass'

const InputDemo = () => {
  const [manualInput, setManualInput] = useState('')
  const [autoInput, setAutoInput] = useState('')

  useEffect(() => {
    // Setup automatic input overlay for focused elements
    const cleanupAutoOverlay = setupAutoInputOverlay()

    // Listen for input overlay submissions
    const cleanupSubmitListener = onInputOverlaySubmit((data) => {
      console.log('Input overlay submitted:', data)
    })

    return () => {
      cleanupAutoOverlay()
      cleanupSubmitListener()
    }
  }, [])

  const handleManualTrigger = () => {
    showInputOverlay({
      targetElement: null,
      initialValue: manualInput,
      preferredMode: 'keyboard'
    })
  }

  const handleDrawingTrigger = () => {
    showInputOverlay({
      targetElement: null,
      initialValue: manualInput,
      preferredMode: 'drawing'
    })
  }

  return (
    <div className="input-demo">
      <h3>🎯 Intelligente Eingabehilfe</h3>
      
      <div className="demo-section">
        <h4>⚡ Automatische Aktivierung</h4>
        <p>Klicken Sie in die Eingabefelder unten, um die Eingabehilfe automatisch zu öffnen:</p>
        <input
          type="text"
          placeholder="Klicken Sie hier für Tastatur-Eingabe..."
          value={autoInput}
          onChange={(e) => setAutoInput(e.target.value)}
          className="demo-input"
        />
        <textarea
          placeholder="Oder hier für längere Texte..."
          value={autoInput}
          onChange={(e) => setAutoInput(e.target.value)}
          className="demo-textarea"
        />
      </div>

      <div className="demo-section">
        <h4>🎮 Manuelle Steuerung</h4>
        <p>Verwenden Sie die Buttons unten, um die Eingabehilfe manuell zu öffnen:</p>
        <div className="demo-controls">
          <button onClick={handleManualTrigger} className="demo-btn demo-btn--keyboard">
            ⌨️ Tastatur öffnen
          </button>
          <button onClick={handleDrawingTrigger} className="demo-btn demo-btn--drawing">
            ✍️ Handschrift öffnen
          </button>
        </div>
        <input
          type="text"
          placeholder="Manueller Eingabetext..."
          value={manualInput}
          onChange={(e) => setManualInput(e.target.value)}
          className="demo-input"
          readOnly
        />
      </div>

      <div className="demo-section">
        <h4>📖 Funktionen</h4>
        <ul className="demo-usage">
          <li>Die Eingabehilfe öffnet sich automatisch bei Fokus auf Eingabefelder</li>
          <li>Wählen Sie zwischen Tastatur-Eingabe und Handschrift-Erkennung</li>
          <li>Die OCR unterstützt deutsche Texterkennung mit Tesseract.js</li>
          <li>Verwenden Sie ESC zum Schließen oder klicken Sie außerhalb der Eingabehilfe</li>
          <li>Vollständig responsive für Touch-Displays und mobile Geräte</li>
        </ul>
      </div>
    </div>
  )
}

export default InputDemo
